@@ -1,7 +1,7 @@
 package Bencher;
 
-our $DATE = '2015-10-11'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2015-10-14'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -24,10 +24,12 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 0.03 of Bencher (from Perl distribution Bencher), released on 2015-10-11.
+This document describes version 0.04 of Bencher (from Perl distribution Bencher), released on 2015-10-14.
 
 =head1 SYNOPSIS
 
+See L<bencher> CLI.
+
 =head1 DESCRIPTION
 
 B<EARLY WORK, LOTS OF UNIMPLEMENTED STUFFS.>
@@ -134,6 +136,8 @@ Can be overriden in the CLI with C<--on-failure> option.
 
 =head1 SEE ALSO
 
+L<bencher>
+
 B<BenchmarkAnything>. There are lot of overlaps of goals between Bencher and
 this project. I hope to reuse or interoperate parts of BenchmarkAnything, e.g.
 storing Bencher results in a BenchmarkAnything storage backend, sending Bencher
